@@ -1,6 +1,7 @@
-# $Id: command.rb,v 1.75 2005/09/13 08:57:46 fdiary Exp $
+# $Id: command.rb,v 1.81 2006/07/03 01:19:13 fdiary Exp $
 # Copyright (C) 2002-2004 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 
+require 'timeout'
 require 'hiki/page'
 require 'hiki/util'
 require 'hiki/plugin'
@@ -66,34 +67,36 @@ module Hiki
     end
 
     def dispatch
-      @cmd = 'view' unless @cmd
       begin
-        raise if !@p && ['view', 'edit', 'diff', 'save'].index( @cmd )
-        if @cmd == 'edit'
-          raise PermissionError, 'Permission denied' unless @plugin.editable?
-          cmd_edit( @p )
-        elsif @cmd == 'save'
-          raise PermissionError, 'Permission denied' unless @plugin.editable?
-          if @params['save'][0]
-            cmd_save(@p, @params['contents'][0], @params['md5hex'][0], @params['update_timestamp'][0])
-          elsif @params['preview'][0]
-            cmd_preview
-          elsif @params['edit_form_button'][0]
-            @cmd = 'edit'
-            cmd_plugin(false)
-            cmd_edit( @p, @plugin.text )
-          end
-        elsif @cmd == 'create'  
-          raise PermissionError, 'Permission denied' unless @plugin.editable?
-          send( "cmd_#{@cmd}" )
-        else
-          if @conf.use_plugin and @plugin.plugin_command.index(@cmd) and @plugin.respond_to?(@cmd)
-            @plugin.send( @cmd )
-          else
+        Timeout.timeout(@conf.timeout) {
+          @cmd = 'view' unless @cmd
+          raise if !@p && ['view', 'edit', 'diff', 'save'].index( @cmd )
+          if @cmd == 'edit'
+            raise PermissionError, 'Permission denied' unless @plugin.editable?
+            cmd_edit( @p )
+          elsif @cmd == 'save'
+            raise PermissionError, 'Permission denied' unless @plugin.editable?
+            if @params['save'][0]
+              cmd_save(@p, @params['contents'][0], @params['md5hex'][0], @params['update_timestamp'][0])
+            elsif @params['edit_form_button'][0]
+              @cmd = 'edit'
+              cmd_plugin(false)
+              cmd_edit( @p, @plugin.text )
+            else
+              cmd_preview
+            end
+          elsif @cmd == 'create'  
+            raise PermissionError, 'Permission denied' unless @plugin.editable?
             send( "cmd_#{@cmd}" )
+          else
+            if @conf.use_plugin and @plugin.plugin_command.index(@cmd) and @plugin.respond_to?(@cmd)
+              @plugin.send( @cmd )
+            else
+              send( "cmd_#{@cmd}" )
+            end
           end
-        end
-      rescue NoMethodError, PermissionError
+        }
+      rescue NoMethodError, PermissionError, Timeout::Error
         data = get_common_data( @db, @plugin, @conf )
         data[:message] = CGI::escapeHTML( $!.message )
         generate_error_page( data )
@@ -207,12 +210,13 @@ module Hiki
     end
 
     def cmd_index
-      list = @db.page_info.sort {|a, b|
-        info_a = a.values[0]
-        title_a = (info_a[:title] and info_a[:title].size > 0) ? info_a[:title] : a.keys[0]
-        info_b = b.values[0]
-        title_b = (info_b[:title] and info_b[:title].size > 0) ? info_b[:title] : b.keys[0]
-        title_a.downcase <=> title_b.downcase
+      list = @db.page_info.sort_by {|e|
+        k,v = e.to_a.first
+        if v[:title] && !v[:title].empty?
+          v[:title].downcase
+        else
+          k.downcase
+        end
       }.collect {|f|
         k = f.keys[0]
         editor = f[k][:editor] ? "by #{f[k][:editor]}" : ''
@@ -242,11 +246,10 @@ module Hiki
     end
 
     def get_recent
-      list = @db.page_info.sort {|a, b|
-        k1 = a.keys[0]
-        k2 = b.keys[0]
-        b[k2][:last_modified] <=> a[k1][:last_modified]
-      }
+      list = @db.page_info.sort_by {|e|
+        k,v = e.to_a.first
+        v[:last_modified]
+      }.reverse
 
       last_modified = list[0].values[0][:last_modified]
 
@@ -340,7 +343,7 @@ module Hiki
     def cmd_save( page, text, md5hex, update_timestamp = true )
       raise PermissionError if @session_id && @session_id != @cgi.params['session_id'][0]
       subject = ''
-      if text.size == 0 && @plugin.admin?
+      if text.empty?
         @db.delete( page )
         @plugin.delete_proc
         data             = get_common_data( @db, @plugin, @conf )
