@@ -1,10 +1,10 @@
-# $Id: config.rb,v 1.92 2005/09/29 07:09:34 fdiary Exp $
+# $Id: config.rb,v 1.113 2006/07/03 01:19:13 fdiary Exp $
 # Copyright (C) 2004-2005 Kazuhiko <kazuhiko@fdiary.net>
 #
 # TADA Tadashi <sho@spc.gr.jp> holds the copyright of Config class.
 
-HIKI_VERSION  = '0.8.4'
-HIKI_RELEASE_DATE = '2005-09-29'
+HIKI_VERSION  = '0.8.6'
+HIKI_RELEASE_DATE = '2006-07-03'
 
 require 'cgi'
 require 'hiki/command'
@@ -55,7 +55,7 @@ module Hiki
     end
 
     def mobile_agent?
-      %r[(DoCoMo|J-PHONE|Vodafone|MOT-|UP\.Browser|DDIPOCKET|ASTEL|PDXGW|Palmscape|Xiino|sharp pda browser|Windows CE|L-mode)]i =~ ENV['HTTP_USER_AGENT']
+      %r[(DoCoMo|J-PHONE|Vodafone|WILLCOM|MOT-|UP\.Browser|DDIPOCKET|ASTEL|PDXGW|Palmscape|Xiino|sharp pda browser|Windows CE|L-mode)]i =~ ENV['HTTP_USER_AGENT']
     end
 
     #
@@ -120,7 +120,6 @@ module Hiki
 
     # loading hikiconf.rb in current directory
     def load
-      @secure = true unless @secure
       @options = {}
       eval( File::open( "hikiconf.rb" ){|f| f.read }.untaint, binding, "(hikiconf.rb)", 1 )
       formaterror if $data_path
@@ -134,7 +133,7 @@ module Hiki
       @site_name     ||= 'Hiki'
       @author_name   ||= ''
       @mail_on_update||= false
-      @mail          ||= ''
+      @mail          ||= []
       @theme         ||= 'hiki'
       @theme_url     ||= 'theme'
       @theme_path    ||= 'theme'
@@ -154,7 +153,7 @@ module Hiki
       @use_wikiname    = true if @use_wikiname.nil?
       @options         = {} unless @options.class == Hash
 
-      @xmlrpc_enabled  ||= true
+      @xmlrpc_enabled  = true unless defined?(@xmlrpc_enabled)
 
       @template_path   ||= "#{PATH}/template"
       @plugin_path     ||= "#{PATH}/plugin"
@@ -187,6 +186,7 @@ module Hiki
       @max_name_size   ||= 50 
       @password        ||= ''
       @generator       ||= "Hiki #{HIKI_VERSION}"
+      @timeout         ||= 30
 
       Dir.mkdir(@cache_path) unless File::directory?(@cache_path)
 
@@ -215,6 +215,7 @@ module Hiki
         variables.each do |var| eval "@#{var} = #{var} if #{var} != nil" end
       rescue IOError, Errno::ENOENT
       end
+      @mail = [@mail].flatten # for backward compatibility
       if @options2 then
         @options.update( @options2 )
       else
