@@ -1,4 +1,4 @@
-# $Id: interwiki.rb,v 1.9 2005/06/28 05:39:08 fdiary Exp $
+# $Id: interwiki.rb,v 1.10 2005/12/28 23:42:18 fdiary Exp $
 # Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 
 module Hiki
@@ -31,12 +31,10 @@ module Hiki
                else
                  p
                end
-        if encoding == 'alias'
-          ["#{@interwiki_names[s][:url]}", s.escapeHTML]
-        elsif @interwiki_names[s][:url].index('$1')
-          [@interwiki_names[s][:url].dup.sub(/\$1/, page), display_text]
+        if @interwiki_names[s][:url].index('$1')
+          [@interwiki_names[s][:url].dup.sub(/\$1/, page).escapeHTML, display_text]
         else
-          ["#{@interwiki_names[s][:url]}#{page}", display_text]
+          ["#{@interwiki_names[s][:url]}#{page}".escapeHTML, display_text]
         end
       else
         nil
@@ -45,7 +43,7 @@ module Hiki
 
     def outer_alias(s)
       if @interwiki_names.has_key?(s) && @interwiki_names[s][:encoding] == 'alias'
-	return [@interwiki_names[s][:url], s.escapeHTML]
+	return [@interwiki_names[s][:url].escapeHTML, s.escapeHTML]
       else
 	return nil
       end
