@@ -1,10 +1,11 @@
-# $Id: plugin.rb,v 1.30 2005/07/17 15:19:01 fdiary Exp $
+# $Id: plugin.rb,v 1.34 2006/02/27 11:56:38 yanagita Exp $
 # Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 # Copyright (C) 2004-2005 Kazuhiko <kazuhiko@fdiary.net>
 #
 # TADA Tadashi <sho@spc.gr.jp> holds the copyright of Config class.
 
 require 'cgi'
+require 'uri'
 require 'hiki/util'
 
 module Hiki
@@ -82,9 +83,12 @@ module Hiki
     end
 
     def cookie_path
-      ret = File::dirname( @options['cgi'].script_name )
-      ret += '/' unless %r|/+$| =~ ret
-      ret
+      path = URI(@conf.base_url).path
+      if path[-1] == ?/
+        path
+      else
+        File.dirname(path) + '/'
+      end
     end
 
     def header_proc
@@ -100,8 +104,6 @@ module Hiki
     end
 
     def update_proc
-      return unless @conf.use_plugin
-      
       @update_procs.each do |proc|
         begin
           proc.call
@@ -111,8 +113,6 @@ module Hiki
     end
 
     def delete_proc
-      return unless @conf.use_plugin
-      
       @delete_procs.each do |proc|
         begin
           proc.call
@@ -122,8 +122,6 @@ module Hiki
     end
     
     def body_enter_proc
-      return '' unless @conf.use_plugin
-
       r = []
       @body_enter_procs.each do |proc|
         begin
@@ -136,9 +134,7 @@ module Hiki
     end
 
     def body_leave_proc
-      return '' unless @conf.use_plugin
       r = []
-
       @body_leave_procs.each do |proc|
         begin
           r << proc.call( @date )
@@ -150,9 +146,7 @@ module Hiki
     end
 
     def page_attribute_proc
-      return '' unless @conf.use_plugin
       r = []
-
       @page_attribute_procs.each do |proc|
         begin
           r << proc.call( @date )
@@ -164,9 +158,7 @@ module Hiki
     end
 
     def footer_proc
-#      return '' unless @conf.use_plugin
       r = []
-
       @footer_procs.each do |proc|
         begin
           r << proc.call
@@ -178,9 +170,7 @@ module Hiki
     end
 
     def edit_proc
-      return '' unless @conf.use_plugin
       r = []
-
       @edit_procs.each do |proc|
         begin
           r << proc.call
@@ -192,9 +182,7 @@ module Hiki
     end
       
     def form_proc
-      return '' unless @conf.use_plugin
       r = []
-
       @form_procs.each do |proc|
         begin
           r << proc.call
@@ -206,9 +194,7 @@ module Hiki
     end
     
     def menu_proc
-      return '' unless @conf.use_plugin
       r = []
-
       @menu_procs.each do |proc|
         begin
           r << proc.call
@@ -295,8 +281,8 @@ module Hiki
 
     def save( page, src, md5, update_timestamp = true )
       src.gsub!(/\r/, '')
-      src.strip!
-      src << "\n"
+      src.sub!(/\A\n*/, '')
+      src.sub!(/\n*\z/, "\n")
       result = @db.store(page, src, md5, update_timestamp)
       if result
         @db.set_attribute( page, :editor => @user )
