@@ -1,4 +1,4 @@
-# $Id: bbs.rb,v 1.8 2005/07/13 05:03:20 fdiary Exp $
+# $Id: bbs.rb,v 1.9 2005/07/20 06:08:51 fdiary Exp $
 # Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 
 add_body_enter_proc(Proc.new do
@@ -6,9 +6,10 @@ add_body_enter_proc(Proc.new do
   ""
 end)
 
-def bbs
+def bbs(level = 1)
   @bbs_num += 1
   name = @user || ''
+  level = (Integer(level) rescue 1)
 
   <<EOS
 <form action="#{@conf.cgi_name}" method="post">
@@ -18,6 +19,7 @@ def bbs
     <textarea cols="60" rows="8" name="msg" size="40"></textarea><br>
     <input type="submit" name="comment" value="#{bbs_post_label}">
     <input type="hidden" name="bbs_num" value="#{@bbs_num}">
+    <input type="hidden" name="bbs_level" value="#{level}">
     <input type="hidden" name="c" value="plugin">
     <input type="hidden" name="p" value="#{@page.escapeHTML}">
     <input type="hidden" name="plugin" value="bbs_post">
@@ -29,6 +31,7 @@ end
 def bbs_post
   params     = @cgi.params
   bbs_num    = (params['bbs_num'][0] || 0).to_i
+  bbs_level  = (params['bbs_level'][0] || 1).to_i
   name       = params['name'][0].size == 0 ? bbs_anonymous_label : params['name'][0]
   subject    = (params['subject'][0].size == 0 ? bbs_notitle_label : params['subject'][0])
   msg        = params['msg'][0]
@@ -43,10 +46,10 @@ def bbs_post
 
   content = ''
   lines.each do |l|
-    if /^\{\{bbs\}\}/ =~ l && flag == false
+    if /^\{\{bbs\b(:?[^\}]*)?\}\}/ =~ l && flag == false
       if count == bbs_num
         content << "#{l}\n"
-        content << @conf.parser.heading( "#{subject} - #{name} (#{format_date(Time::now)})\n" )
+        content << @conf.parser.heading( "#{subject} - #{name} (#{format_date(Time::now)})\n", bbs_level )
         content << "#{msg}\n"
         content << "{{comment}}\n"
         flag = true
