@@ -1,4 +1,4 @@
-# $Id: rss.rb,v 1.1 2005/08/02 13:37:41 yanagita Exp $
+# $Id: rss.rb,v 1.2 2005/09/06 06:08:29 fdiary Exp $
 # Copyright (C) 2003-2004 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 # Copyright (C) 2005 Kazuhiko <kazuhiko@fdiary.net>
 
@@ -11,7 +11,8 @@ def label_rss_mode_title; 'Formatauswahl.'; end
 def label_rss_mode_candidate
   [ 'unified diff',
     'word diff (Auszug)',
-    'word diff (voller Text)', ]
+    'word diff (voller Text)',
+    'HTML (voller Text)', ]
 end
 def label_rss_menu_title; 'RSS Men&uuml; hinzuf&uuml;gen'; end
 def label_rss_menu_candidate
