@@ -1,4 +1,4 @@
-# $Id: rss.rb,v 1.4 2005/06/08 06:02:38 fdiary Exp $
+# $Id: rss.rb,v 1.5 2005/09/06 06:08:29 fdiary Exp $
 # Copyright (C) 2003-2004 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 # Copyright (C) 2005 Kazuhiko <kazuhiko@fdiary.net>
 
@@ -11,7 +11,8 @@ def label_rss_mode_title; 'Select the format.'; end
 def label_rss_mode_candidate
   [ 'unified diff',
     'word diff (digest)',
-    'word diff (full text)', ]
+    'word diff (full text)',
+    'HTML (full text)', ]
 end
 def label_rss_menu_title; 'add RSS menu'; end
 def label_rss_menu_candidate
