@@ -1,4 +1,4 @@
-# $Id: rss.rb,v 1.18 2005/06/08 06:02:37 fdiary Exp $
+# $Id: rss.rb,v 1.22 2005/09/11 10:10:30 fdiary Exp $
 # Copyright (C) 2003-2004 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 # Copyright (C) 2005 Kazuhiko <kazuhiko@fdiary.net>
 
@@ -27,7 +27,6 @@ def rss_body(page_num = 10)
     <items>
       <rdf:Seq>
 EOS
-
   pages.each do |p|
     break if (n += 1) > page_num
     name = p.keys[0]
@@ -39,10 +38,23 @@ EOS
       content = word_diff(src, dst, true).strip.gsub(/\n/, "<br>\n")
     when 2
       content = word_diff(src, dst).strip.gsub(/\n/, "<br>\n")
+    when 3
+      tokens = @db.load_cache( name )
+      unless tokens
+        parser = @conf.parser::new( @conf )
+        tokens = parser.parse( @db.load( name ) )
+        @db.save_cache( name, tokens )
+      end
+      tmp = @conf.use_plugin
+      @conf.use_plugin = false
+      formatter = @conf.formatter::new( tokens, @db, Plugin.new( @conf.options, @conf), @conf )
+      content = formatter.to_s
+      @conf.use_plugin = tmp
     else
       content = CGI::escapeHTML(unified_diff(src, dst)).strip.gsub(/\n/, "<br>\n").gsub(/ /, '&nbsp;')
     end
-    if content.empty?
+
+    if content and content.empty?
       content = shorten(dst).strip.gsub(/\n/, "<br>\n")
     end
     
@@ -56,9 +68,9 @@ EOS
     <title>#{CGI::escapeHTML(page_name(name))}</title>
     <link>#{uri}</link>
     <dc:date>#{p[name][:last_modified].utc.strftime('%Y-%m-%dT%H:%M:%S+00:00')}</dc:date>
-    <content:encoded><![CDATA[<div>#{content}</div>]]></content:encoded>
-  </item>
 EOS
+    item_list << "    <content:encoded><![CDATA[<div>#{content}</div>]]></content:encoded>" if content
+    item_list << '  </item>'
   end
 
   items << <<EOS
@@ -74,14 +86,27 @@ end
 def rss
   body, last_modified = rss_body
   header = Hash::new
-  header['Last-Modified'] = CGI::rfc1123_date(last_modified)
-  header['type']          = 'text/xml'
-  header['charset']       =  @conf.charset
-  header['Content-Language'] = @conf.lang
-  header['Pragma']           = 'no-cache'
-  header['Cache-Control']    = 'no-cache'
-  print @cgi.header(header)
-  puts body
+
+  require 'time'
+  begin
+    if_modified_since = Time.parse(ENV['HTTP_IF_MODIFIED_SINCE'])
+  rescue
+    if_modified_since = nil
+  end
+
+  if if_modified_since and last_modified < if_modified_since
+    header['status'] = 'NOT_MODIFIED'
+    print @cgi.header(header)
+  else
+    header['Last-Modified'] = CGI::rfc1123_date(last_modified)
+    header['type']          = 'text/xml'
+    header['charset']       =  @conf.charset
+    header['Content-Language'] = @conf.lang
+    header['Pragma']           = 'no-cache'
+    header['Cache-Control']    = 'no-cache'
+    print @cgi.header(header)
+    puts body
+  end
 
   nil # Don't move to the 'FrontPage'
 end
