@@ -1,4 +1,4 @@
-# $Id: 00default.rb,v 1.51 2005/09/20 11:12:24 fdiary Exp $
+# $Id: 00default.rb,v 1.55 2006/06/01 10:54:50 fdiary Exp $
 # Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 
 #==============================
@@ -63,7 +63,7 @@ def toc_here( page = nil )
     end
     formatter = @conf.formatter::new( tokens, @db, Plugin.new( @conf.options, @conf), @conf )
     formatter.to_s
-    formatter.toc.gsub( /<a href="/, %Q|<a href="#{hiki_url( page )}| )
+    formatter.toc.gsub( /<a href="/, "<a href=\"#{hiki_url( page )}" )
   else
     @toc_f ||= :here
     TOC_STRING
@@ -97,7 +97,7 @@ def recent( n = 20 )
     end
     t = page_name(name)
     an = hiki_anchor(name.escape, t)
-    s << "<li>#{an}\n"
+    s << "<li>#{an}</li>\n"
   end
   s << "</ul>\n"
   s
@@ -227,7 +227,12 @@ def saveconf_default
   if @mode == 'saveconf' then
     @conf.site_name = @cgi.params['site_name'][0]
     @conf.author_name = @cgi.params['author_name'][0]
-    @conf.mail = @cgi.params['mail'][0]
+    mails = []
+    @cgi.params['mail'][0].each_line do |addr|
+      mails << addr.gsub(/\r?\n/, '').strip
+    end
+    mails.delete_if{|e| e.empty?}
+    @conf.mail = mails
     @conf.mail_on_update = @cgi.params['mail_on_update'][0] == "true"
   end
 end
@@ -257,7 +262,7 @@ def saveconf_theme
 end
 
 if @cgi.params['conf'][0] == 'theme' && @mode == 'saveconf'
-  @conf.theme          = @cgi.params['theme'][0]
+  @conf.theme          = @cgi.params['theme'][0] || ''
   @conf.use_sidebar    = @cgi.params['sidebar'][0] == "true"
   @conf.main_class     = @cgi.params['main_class'][0]
   @conf.main_class     = 'main' if @conf.main_class == ''
@@ -272,7 +277,7 @@ end
 if @cgi.params['conf'][0] == 'theme'
   @conf_theme_list = []
   Dir::glob( "#{@conf.theme_path}/*".untaint ).sort.each do |dir|
-    theme = dir.sub( %r[(.*/)?theme/], '')
+    theme = File::basename( dir )
     next unless FileTest::file?( "#{dir}/#{theme}.css".untaint )
     name = theme.split( /_/ ).collect{|s| s.capitalize}.join( ' ' )
     @conf_theme_list << [theme,name]
